@@ -333,7 +333,7 @@ void Retuner::findcycle (void)
         j += d;
     }
     fftwf_execute_dft_r2c (_fwdplan, _fftTdata, _fftFdata);    
-    f = _fsamp / (_fftlen * 2.5e3f);
+    f = _fsamp / (_fftlen * 5e3f);
     for (i = 0; i < h; i++)
     {
         x = _fftFdata [i][0];
